"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

var _core = require("@emotion/core");

var _colors = require("@atlaskit/theme/colors");

var _constants = require("@atlaskit/theme/constants");

/** @jsx jsx */
var defaultAppearanceStyles = (0, _core.css)({
  backgroundColor: "var(--ds-background-subtleNeutral-resting, ".concat(_colors.N40, ")"),
  color: "var(--ds-text-highEmphasis, ".concat(_colors.N500, ")")
});
var inprogressAppearanceStyles = (0, _core.css)({
  backgroundColor: "var(--ds-background-subtleBrand-resting, ".concat(_colors.B50, ")"),
  color: "var(--ds-text-brand, ".concat(_colors.B500, ")")
});
var movedAppearanceStyles = (0, _core.css)({
  backgroundColor: "var(--ds-background-subtleWarning-resting, ".concat(_colors.Y75, ")"),
  color: "var(--ds-text-warning, ".concat(_colors.N800, ")")
});
var newAppearanceStyles = (0, _core.css)({
  backgroundColor: "var(--ds-background-subtleDiscovery-resting, ".concat(_colors.P50, ")"),
  color: "var(--ds-text-discovery, ".concat(_colors.P500, ")")
});
var removedAppearanceStyles = (0, _core.css)({
  backgroundColor: "var(--ds-background-subtleDanger-resting, ".concat(_colors.R50, ")"),
  color: "var(--ds-text-danger, ".concat(_colors.R500, ")")
});
var successAppearanceStyles = (0, _core.css)({
  backgroundColor: "var(--ds-background-subtleSuccess-resting, ".concat(_colors.G50, ")"),
  color: "var(--ds-text-success, ".concat(_colors.G500, ")")
});
var defaultBoldAppearanceStyles = (0, _core.css)({
  backgroundColor: "var(--ds-background-boldNeutral-resting, ".concat(_colors.N500, ")"),
  color: "var(--ds-text-onBold, ".concat(_colors.N0, ")")
});
var inprogressBoldAppearanceStyles = (0, _core.css)({
  backgroundColor: "var(--ds-background-boldBrand-resting, ".concat(_colors.B400, ")"),
  color: "var(--ds-text-onBold, ".concat(_colors.N0, ")")
});
var movedBoldAppearanceStyles = (0, _core.css)({
  backgroundColor: "var(--ds-background-boldWarning-resting, ".concat(_colors.Y500, ")"),
  color: "var(--ds-text-onBoldWarning, ".concat(_colors.N800, ")")
});
var newBoldAppearanceStyles = (0, _core.css)({
  backgroundColor: "var(--ds-background-boldDiscovery-resting, ".concat(_colors.P400, ")"),
  color: "var(--ds-text-onBold, ".concat(_colors.N0, ")")
});
var removedBoldAppearanceStyles = (0, _core.css)({
  backgroundColor: "var(--ds-background-boldDanger-resting, ".concat(_colors.R400, ")"),
  color: "var(--ds-text-onBold, ".concat(_colors.N0, ")")
});
var successBoldAppearanceStyles = (0, _core.css)({
  backgroundColor: "var(--ds-background-boldSuccess-resting, ".concat(_colors.G400, ")"),
  color: "var(--ds-text-onBold, ".concat(_colors.N0, ")")
});
var subtleAppearances = {
  default: defaultAppearanceStyles,
  inprogress: inprogressAppearanceStyles,
  moved: movedAppearanceStyles,
  new: newAppearanceStyles,
  removed: removedAppearanceStyles,
  success: successAppearanceStyles
};
var boldAppearances = {
  default: defaultBoldAppearanceStyles,
  inprogress: inprogressBoldAppearanceStyles,
  moved: movedBoldAppearanceStyles,
  new: newBoldAppearanceStyles,
  removed: removedBoldAppearanceStyles,
  success: successBoldAppearanceStyles
};
var contentStyles = (0, _core.css)({
  display: 'inline-block',
  boxSizing: 'border-box',
  width: '100%',
  padding: "0 ".concat((0, _constants.gridSize)() / 2, "px"),
  overflow: 'hidden',
  textOverflow: 'ellipsis',
  verticalAlign: 'top',
  whiteSpace: 'nowrap'
});
var containerStyles = (0, _core.css)({
  display: 'inline-block',
  boxSizing: 'border-box',
  maxWidth: '100%',
  padding: '2px 0 3px 0',
  borderRadius: (0, _constants.borderRadius)(),
  fontSize: '11px',
  fontWeight: 700,
  lineHeight: 1,
  textTransform: 'uppercase',
  verticalAlign: 'baseline'
});
/**
 * __Lozenge__
 *
 * A lozenge is a visual indicator used to highlight an item's status for quick recognition.
 *
 * - [Examples](https://atlassian.design/components/lozenge/examples)
 * - [Code](https://atlassian.design/components/lozenge/code)
 * - [Usage](https://atlassian.design/components/lozenge/usage)
 */

var Lozenge = /*#__PURE__*/(0, _react.memo)(function (_ref) {
  var children = _ref.children,
      testId = _ref.testId,
      _ref$isBold = _ref.isBold,
      isBold = _ref$isBold === void 0 ? false : _ref$isBold,
      _ref$appearance = _ref.appearance,
      appearance = _ref$appearance === void 0 ? 'default' : _ref$appearance,
      _ref$maxWidth = _ref.maxWidth,
      maxWidth = _ref$maxWidth === void 0 ? 200 : _ref$maxWidth,
      _ref$style = _ref.style,
      style = _ref$style === void 0 ? {} : _ref$style;
  return (0, _core.jsx)("span", {
    style: {
      backgroundColor: style.backgroundColor,
      color: style.color
    },
    css: [isBold ? boldAppearances[appearance] : subtleAppearances[appearance], containerStyles],
    "data-testid": testId
  }, (0, _core.jsx)("span", {
    style: {
      maxWidth: maxWidth
    },
    css: contentStyles
  }, children));
});
Lozenge.displayName = 'Lozenge';
var _default = Lozenge;
exports.default = _default;